import * as Types from '../types/types';
import { BaseAction } from '../abstract/base-action';
export default abstract class Utilities {
    abstract deleteTrigger(uuid: string): void;
    abstract fetch(path: string, options?: any): Promise<any>;
    abstract getNodeBinaryPath(): string;
    abstract getMdlsName(applicationPath: string): string;
    abstract performanceNow: any;
    /** Base, environment agnostic methods */
    /**
     * Returns a base url for the BTT webserver endpoint
     */
    getUrl(config: Partial<Types.AppConfig>): string;
    /**
     * Sends a request to real BTT built in webserver with given data translated as GET query params
     */
    callBetterTouchTool(action: string, data: Types.BttPayload, config: Types.AppConfig, translate?: boolean): Promise<Types.CallResult>;
    /**
     * Builds the url that'll trigger desired action
     * @param action
     * @param params
     * @param baseUrl
     */
    buildFullUrl(action: string, params: string, baseUrl: string): string;
    /**
     * Parses given list of params (key-value object) and converts it
     * to query parameters
     */
    params(data: Record<string, string>, sharedKey?: string): string;
    /**
     * Maps each key in the passed object to btt notation (BTTWhateverPassed)
     * @param key
     */
    translateObjectKeysToBttNotation(object: Partial<Types.AppPayload> | Partial<Types.BttPayload>): Partial<Record<string, any>>;
    /**
     * Maps given string to btt JSON key notation
     * @example 'triggerName' => 'BTTTriggerName'
     * @param key
     */
    keyToBttNotation(key: string): string;
    /**
     * Parses given string to simplified lower case
     * @param string
     */
    simpleCase(string: string): string;
    /**
     * Returns the current UUID representing the namespace of the package
     */
    readonly namespace: string;
    /**
     * Returns a base url for the BTT webserver endpoint
     */
    getBaseUrl(config: Partial<Types.AppConfig>): string;
    /**
     * Takes a namespace as a parameter and a text, to generate an UUID (uuidv5)
     * @param text
     * @param namespace
     */
    generateUuidForString(text: string, namespace?: string): string;
    /**
     * Parses given class name to simplified notation
     * @param theClass
     * @example Class AShowHUD { } => showhud
     */
    mapClassNameToMethodName(theClass: Types.Class<BaseAction>): string;
}
