import ActionInvoker from '../abstract/action-invoker';
import * as Initializer from '../types/initializers';
import * as Types from '../types/types';
export default class Chain extends ActionInvoker {
    private config;
    constructor(config: Types.AppConfig);
    private totalQueue;
    /**
     * Sends shortcut to txhe application. Some apps need to have focus so they can recieve shortcuts.
     *
     * @param shortcut key identifiers separated by space
     * @param applicationPath absolute path pointing to the app which should recieve shortcut
     * @param applicationPath required for BTT to recognize the app, whithin browser env must be provided manually
     */
    sendShortcut: Initializer.ChainSendShortcut;
    /**
     * Executes passed nodejs script. Requires manual specificying of node executable binary if used on frontend
     *
     * @param code a code to run
     */
    executeScript: Initializer.ChainExecuteScript;
    /**
     * Toggles do not disturb mode
     */
    toggleDnD: Initializer.ChainToggleDnD;
    /**
     * Toggles do not disturb mode
     */
    toggleTrueTone: Initializer.ChainToggleTrueTone;
    /**
     * Toggles night shift
     */
    toggleNightShift: Initializer.ChainToggleNightShift;
    /**
     * Triggers system wide keyboard shortcut
     * @param shortcut key identifiers separated by space
     */
    triggerShortcut: Initializer.ChainTriggerShortcut;
    /**
     * Shows HUD with given config
     */
    showHUD: Initializer.ChainShowHUD;
    /**
     * Sends / Types / Inserts / Pastes custom text
     */
    sendText: Initializer.ChainSendText;
    /**
     * Triggers a haptic response. Takes a number as a param due to BTT lack of information
     * which ID represents which mode, in order to know what value represents what open BTT and map
     * the order of selects options in config of "Perform Haptic Feedback on Trackpad" action
     *
     * @param hapticMode a number representing each mode.
     */
    hapticFeedback: Initializer.ChainHapticFeedback;
    /**
     * Open an application on the given path
     */
    launchApplication: Initializer.ChainLaunchApplication;
    /**
     * Toggles the visibility of given application
     */
    toggleApplication: Initializer.ChainToggleApplication;
    /**
     * Toggles the mute state in the system
     */
    mute: Initializer.ChainMute;
    /**
     * Starts Siri
     */
    startSiri: Initializer.ChainStartSiri;
    /**
     * Delays the next action. For most cases manually managing the execution of actions in JavaScript
     * should be sufficient - using this will block any new action that BTT will recieve
     *
     * @param timeout - time in miliseconds during any action execution will be delayed
     */
    delayNextAction: Initializer.ChainDelayNextAction;
    /**
     * Moves mouse to specified position
     */
    moveMouse: Initializer.ChainMoveMouse;
    /**
     * Toggles the mouse speed between a regular and speeded up one
     */
    toggleMouseSpeed: Initializer.ChainToggleMouseSpeed;
    /**
     * Toggles mouse cursor visibility
     */
    toggleMouseCursor: Initializer.ChainToggleMouseCursor;
    /**
     * Toggles between the big and regular mouse cursor size
     */
    toggleMouseSize: Initializer.ChainToggleMouseSize;
    /**
     * Toggles the system dark mode
     */
    toggleDarkMode: Initializer.ChainToggleDarkMode;
    /**
     * Opens a web view
     */
    showWebView: Initializer.ChainShowWebView;
    /**
     * Saves selected text to variable selected_text
     * This can be later retrieved via btt.state.get('selected_text')
     */
    saveSelectedText: Initializer.ChainSaveSelectedText;
    /**
     * Locks the screen
     */
    lockScreen: Initializer.ChainLockScreen;
    /**
     * Logouts current user
     */
    logout: Initializer.ChainLogout;
    /**
     * Sleeps computer display
     */
    sleepDisplay: Initializer.ChainSleepDisplay;
    /**
     * Sleeps computer
     */
    sleepComputer: Initializer.ChainSleepComputer;
    /**
     * Shows system wide notification. Keep in mind that it's presence depends on the DnD state in the system.
     */
    showNotification: Initializer.ChainShowNotification;
    /**
     * Quits BetterTouchTool
     */
    quit: Initializer.ChainQuitBTT;
    /**
     * Toggles the BetterTouchTool gesture recognition
     */
    toggle: Initializer.ChainToggleBTT;
    /**
     * Restarts BetterTouchTool
     */
    restart: Initializer.ChainRestartBTT;
    /**
     * Allows to invoke previously prepared chain, returns promise
     */
    call(): Promise<any>;
    /**
     * Allows to delay the action execution from JavaScript side. Time in ms
     * @param timeout
     */
    wait(timeout: number): this;
    /**
     * Recursive function that'll invoke the queue elements an remove them from list once resolved
     */
    private updateQueue;
    /**
     * Allows to add new entries to queue
     * @param fn
     */
    private addToQueue;
}
