import { EActions } from '../types/enum';
import * as Types from '../types/types';
/**
 * Basic structure and methods for all Actions
 * Every action implementation derives from this class, should not be called directly
 */
export declare abstract class BaseAction {
    protected config: Types.IBTTConfig;
    protected arguments: any[];
    protected id: EActions;
    /**
     * A constructor for abstract Action class
     * @param args
     */
    constructor(config: Types.IBTTConfig, ...args: any[]);
    /**
     * Returns JSON structure for the current action.
     * Must be overriden by instances
     */
    readonly json: Types.IBetterTouchToolPayload;
    /**
     * Intended to be overriden by action implementation
     * If left as is, simply uses the id of the action and produces required json
     */
    protected readonly data: Partial<Types.IBetterTouchToolPayload>;
    /**
     * Returns the base data of every JSON, required for BTT to see the changes
     */
    private readonly baseData;
    /**
     * Returns the url of the given action, that this library generates
     */
    readonly url: string;
    /**
     * Calls the prepared actions
     */
    invoke(): Promise<any>;
    /**
     * Returns parameters needed for url generation
     */
    protected readonly params: string;
}
