import * as Types from '../types/types';
/**
 * This class is responsible for managing BetterTouchTool variables.
 * It has similar usage to the ES6 Map object, but due to implementation specifics
 * every method retunrs a promise.
 */
export default class VariableStore {
    private config;
    /**
     * Used to instanitilize the variable store with given BTT config
     * @param config
     */
    constructor(config: Types.AppConfig);
    /**
     * Sets the variable name to specific value
     * @param key a name of the variable that is supposed to be saved
     * @param value new value of the variable
     * @param isPersistent whether the variable should persist after BTT reboot
     */
    set(key: string, value: string | number, isPersistent?: boolean): Promise<Types.CallResult>;
    /**
     * Retrieves BTT variable
     * @param key a variable name to retrieve
     * @param mode string or number. Providing this parameter makes this method more efficient
     */
    get(key: string, mode?: 'string' | 'number'): Promise<number | string>;
    /**
     * "Deletes" specified variable. Depending on its type, it'll either be set to '' or -1
     * @param key a variable name that you want to delete
     * @param persistent whether persistent or regular variable should be deleted
     */
    del(key: string, persistent?: boolean): Promise<void>;
}
